.. _advice:

Advice
======

Event and Location Ideas
------------------------

By `Barbara Sharette`_


Ideas for meeting spaces/venues
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

- Local tech company spaces - ask people you know who work there, or ask your own employer if there's a meeting space you can use.
- For companies willing to let you use their meeting spaces, offer them the chance to do a hiring spiel to open the meeting.
- Check with the organizers of other tech meetup groups for venue ideas.
- Contact local hacker spaces
- Contact local coworking spaces
- Contact your local university's CS department

Getting the word out
^^^^^^^^^^^^^^^^^^^^

- Email the organizers of other tech meetup groups to ask them to help advertise your event.
- Put posters up at universities, or contact the CS student society.  Ask the department secretary to contact grad students.
- Partner with other groups for jointly hosted events
- Get business cards to hand out at events
- Set up a Twitter account

Meeting ideas
^^^^^^^^^^^^^

- Workshops with themes/goals (e.g., one workshop on how to build a small webapp, another one where you try to use python to solve some brainteasers)
- Hold a small competition for your group where there's a goal and you split into two teams and try to solve a problem faster, or better (performance, speed, etc.).
- Beginner Python and Git classes
- Get involved with hack days with other local user groups
- Brainstorm ideas for group projects, so that you have a collection of specific projects to work on for hack nights.
- Leverage Google Hangout to offer support to existing members on matters that hinge more on conversation than on in-person hacking  (e.g., PyLadies recently hosted a hangout to chat about the PyCon call for proposals)



Finding Sponsors/Raising Funds
------------------------------

If your chapter is small, you don’t necessarily need sponsors. Hosting chapter meetups at coffee shops, restaurants, or people’s houses is fine.

However, you may want to organize trips, conferences, and other types of more costly events. If so, you will need to raise local chapter funds and ask local Python shops to consider sponsoring an event.

Venue Sponsors
~~~~~~~~~~~~~~
Research local companies and approach them. Often, a company that already hosts other meetups will be willing to host your PyLadies chapter. Ask them if they’ll provide pizza/drinks; if not, charge attendees a fee that covers food (and more, if you want to use the funds for future events).

Fiscal Sponsorship from the PSF
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
The `Python Software Foundation <http://python.org/psf>`_ has been very supportive of PyLadies.  They have a `special donation page <https://psfmember.org/civicrm/contribute/transact?reset=1&id=6>`_,  where donors can use PayPal to make donations directly to the PSF that are tax-deductible, which can then be used to reimburse PyLadies organizers who pay for various event costs.


PSF Grant Programs
~~~~~~~~~~~~~~~~~~

See our sample `PSF grant proposal`_ to raise money for t-shirts, tables, and chairs.

.. _PSF grant proposal: https://github.com/pyladies/pyladies-kit/blob/master/grant-proposals/sample-hackathon.pdf?raw=true

You can apply for a Python Sprints grant to raise money for food, power strips, name tags, and anything else you might need to run a sprint/hackathon, up to $300:


Selling t-shirts/merchandise
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Some PyLadies designs and printing instructions are provided with this kit. The cost is roughly $500-750 for 60 shirts. Shirts can be sold for $20 each (you can adjust the price to meet your needs/currency, of course).

See the “T-Shirts, Stickers, and Other Merchandise” section for more details.

Corporate sponsorship
~~~~~~~~~~~~~~~~~~~~~

Many companies are looking for ways to give back to the developer community. You’ll want to put together a corporate sponsor info packet.

See our sample info packet at upload sponsorship doc to git repo. Borrow ideas from it, and customize it to fit your chapter.

.. _Barbara Sharette: https://twitter.com/bshaurette
